use rbson::Bson;

pub mod limit;
pub mod rule;
pub mod template;

pub use limit::PageLimit;
pub use template::TEMPLATE;
